@@ -54,7 +54,10 @@ def untested(meth):
 
 class IloError(Exception):
     def __init__(self, message, errorcode=None):
-        super(IloError, self).__init__(message)
+        if issubclass(IloError, object):
+            super(IloError, self).__init__(message)
+        else:
+            Exception.__init__(self, message)
         self.errorcode = errorcode
 
 class IloCommunicationError(IloError):
@@ -522,12 +525,12 @@ class Ilo(object):
         root, inner = self._root_element(infotype, MODE='read')
         etree.SubElement(inner, tagname)
         if self.delayed:
-            self._processors.append([self._process_info_tag2, returntag or tagname, process])
+            self._processors.append([self._process_info_tag2, returntag or tagname, key, process])
             return
         header, message = self._request(root)
-        return self._process_info_tag2(message, returntag or tagname, process)
+        return self._process_info_tag2(message, returntag or tagname, key, process)
 
-    def _process_info_tag2(self, message, returntag, process):
+    def _process_info_tag2(self, message, returntag, key, process):
         message = message.find(returntag)
 
         if key:
@@ -550,13 +553,20 @@ class Ilo(object):
         for element in elements:
             inner.append(element)
         if self.delayed:
+            if tagname == 'CERTIFICATE_SIGNING_REQUEST':
+                self._processors.append([self._process_control_tag, returntag or tagname])
             return
         header, message = self._request(root)
+        return self._process_control_tag(message, returntag or tagname)
+
+    def _process_control_tag(self, message, returntag):
         if message is None:
             return None
-        message = message.find(returntag or tagname)
+        message = message.find(returntag)
         if message.text.strip():
             return message.text.strip()
+        if not message.attrib and not list(message):
+            return None
         raise IloError("You've reached unknown territories, please report a bug")
         if list(message):
             return self._element_children_to_dict(message)
